OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "S’shkruhet dot te drejtori \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Zakonisht kjo mund të ndreqet duke i akorduar shërbyesit web të drejta shkrimi mbi drejtorinë e formësimeve",
    "See %s" : "Shihni %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Zakonisht kjo mund të ndreqet duke %si akorduar shërbyesit web të drejta shkrimi mbi drejtorinë e formësimeve%s.",
    "Sample configuration detected" : "U gjet formësim shembull",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "U pa se është kopjuar shembulli për formësime. Kjo mund të prishë instalimin tuaj dhe nuk mbulohet. Ju lutemi, lexoni dokumentimin, përpara se të kryeni ndryshime te config.php",
    "PHP %s or higher is required." : "Lypse PHP %s ose më sipër.",
    "PHP with a version lower than %s is required." : "Lypset PHP me një version më të ulët se sa %s.",
    "%sbit or higher PHP required." : "Lypset PHP %sbit ose më i ri.",
    "Following databases are supported: %s" : "Mbulohen bazat vijuese të të dhënave: %s",
    "The command line tool %s could not be found" : "Mjeti rresht urdhrash %s s’u gjet dot",
    "The library %s is not available." : "Libraria %s s’është e passhme.",
    "Library %s with a version higher than %s is required - available version %s." : "Lypset librari %s me një version më të madh se %s - version gati %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Lypset librari %s me një version më të vogël se %s - version gati %s.",
    "Following platforms are supported: %s" : "Mbulohen platformat vijuese: %s",
    "ownCloud %s or higher is required." : "Lypset ownCloud %s ose më sipër.",
    "ownCloud %s or lower is required." : "Lypset ownCloud %s ose më poshtë.",
    "Unknown filetype" : "Lloj i panjohur kartele",
    "Invalid image" : "Figurë e pavlefshme",
    "Avatar image is not square" : "Figura e avatarit s’është katrore",
    "today" : "sot",
    "yesterday" : "dje",
    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
    "last month" : "muajin e shkuar",
    "_%n month ago_::_%n months ago_" : ["%n muaj më parë","%n muaj më parë"],
    "last year" : "vitin e shkuar",
    "_%n year ago_::_%n years ago_" : ["%n vit më parë","%n vjet më parë"],
    "_%n hour ago_::_%n hours ago_" : ["%n orë më parë","%n orë më parë"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minutë më parë","%n minuta më parë"],
    "seconds ago" : "sekonda më parë",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "S’ka modul me id: %s. Ju lutemi, aktivizojeni te rregullimet tuaja për aplikacionin ose lidhuni me përgjegjësin tuaj.",
    "Builtin" : "I brendshëm",
    "None" : "Asnjë",
    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
    "Empty filename is not allowed" : "Nuk lejohen emra të zbrazët kartelash",
    "Dot files are not allowed" : "Nuk lejohen kartela të fshehura",
    "4-byte characters are not supported in file names" : "Shenjat 4-bajtshe nuk mbulohet në emra kartelash",
    "File name is a reserved word" : "Emri i kartelës është një emër i rezervuar",
    "File name contains at least one invalid character" : "Emri i kartelës përmban të paktën një shenjë të pavlefshme",
    "File name is too long" : "Emri i kartelës është shumë i gjatë",
    "App directory already exists" : "Drejtoria e aplikacionit ekziston tashmë",
    "Can't create app folder. Please fix permissions. %s" : "S’krijohet dot dosje aplikacioni. Ju lutemi, ndreqni lejet. %s",
    "Archive does not contain a directory named %s" : "Arkivi s’përmban një drejtori të quajtur %s",
    "No source specified when installing app" : "S’u dha burim gjatë instalimit të aplikacionit",
    "No href specified when installing app from http" : "S’u tregua href gjatë instalimit të aplikacionit nga http",
    "No path specified when installing app from local file" : "S’u caktua shteg gjatë instalimit të aplikacionit prej kartele vendore",
    "Archives of type %s are not supported" : "Nuk mbulohen arkivat e llojit %s",
    "Failed to open archive when installing app" : "Dështoi në hapje arkivi teksa instalohej aplikacioni",
    "App does not provide an info.xml file" : "Aplikacioni s’ofron kartele të vlefshme .xml",
    "App cannot be installed because appinfo file cannot be read." : "Aplikacioni s’mund të instalohet, ngaqë s’lexohet dot kartela appinfo.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Nënshkrimi s’u kontrollua dot. Ju lutemi, lidhuni me zhvilluesin e aplikacionit dhe kontrolloni te skena juaj e përgjegjësit.",
    "App can't be installed because of not allowed code in the App" : "Aplikacioni s’mund të instalohet, për shkak kodi të palejuar te Aplikacioni",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikacioni s’mund të instalohet, ngaqë s’është i përputhshëm me këtë version të ownCloud-it",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikacioni s’mund të instalohet, ngaqë përmban etiketën <shipped>true</shipped> e cila nuk lejohet për aplikacione që s’janë hedhur në qarkullim",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Aplikacioni s’mund të instalohet, ngaqë versioni te info.xml s’është i njëjti me versionin e treguar nga shitorja e aplikacioneve",
    "Apps" : "Aplikacione",
    "General" : "Të përgjithshme",
    "Storage" : "Depozitë",
    "Security" : "Siguri",
    "User Authentication" : "Mirëfilltësim Përdoruesi",
    "Encryption" : "Fshehtëzim",
    "Workflows & Tags" : "Rrjedha pune & Etiketa",
    "Sharing" : "Ndarje me të tjerët",
    "Search" : "Kërko",
    "Updates" : "Përditësime",
    "Help & Tips" : "Ndihmë & Këshilla",
    "Additional" : "Shtesë",
    "%s enter the database username and name." : "%s jepni emrin e bazës së të dhënave dhe emrin e përdoruesit për të.",
    "%s enter the database username." : "%s jepni emrin e përdoruesit të bazës së të dhënave.",
    "%s enter the database name." : "%s jepni emrin e bazës së të dhënave.",
    "%s you may not use dots in the database name" : "%s s’mund të përdorni pika te emri i bazës së të dhënave",
    "Oracle connection could not be established" : "S’u vendos dot lidhje me Oracle",
    "Oracle username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim Oracle-i i pavlefshëm",
    "DB Error: \"%s\"" : "Gabim DB-je: \"%s\"",
    "Offending command was: \"%s\"" : "Urdhri shkaktar qe: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Lypset të jepni ose një llogari ekzistuese, ose llogarinë e përgjegjësit.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Urdhri shkaktar qe: \"%s\", emër: %s, fjalëkalim: %s",
    "PostgreSQL username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim PostgreSQL jo të vlefshëm",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nuk mbulohet dhe %s s’do të funksionojë si duhet në këtë platformë. Përdoreni nën përgjegjësinë tuaj! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Për përfundimet më të mira, ju lutemi, më mirë konsideroni përdorimin e një shërbyesi GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Duket se kjo instancë %s xhiron një mjedis PHP 32-bitësh dhe open_basedir është e formësuar, te php.ini. Kjo do të shpjerë në probleme me kartela më të mëdha se 4 GB dhe këshillohet me forcë të mos ndodhë.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ju lutemi, hiqeni rregullimin open_basedir nga php.ini juaj ose hidhuni te PHP për 64-bit.",
    "Set an admin username." : "Caktoni një emër përdoruesi për përgjegjësin.",
    "Set an admin password." : "Caktoni një fjalëkalim për përgjegjësin.",
    "Can't create or write into the data directory %s" : "S’e krijon ose s’shkruan dot te drejtoria e të dhënave %s",
    "Invalid Federated Cloud ID" : "ID Federated Cloud e pavlefshme",
    "%s shared »%s« with you" : "%s ndau me ju »%s«",
    "%s via %s" : "%s përmes %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Ndarja e %s dështoi, ngaqë pjesa përgjegjëse e shërbyesit nuk lejon ndarje prej llojit %i",
    "Sharing %s failed, because the file does not exist" : "Ndarja e %s me të tjerët dështoi, ngaqë kartela s’ekziston",
    "You are not allowed to share %s" : "Nuk ju lejohet ta ndani %s me të tjerët",
    "Sharing %s failed, because you can not share with yourself" : "Ndarja e %s dështoi, ngaqë s’mund të ndani gjëra me vetveten",
    "Sharing %s failed, because the user %s does not exist" : "Ndarja e %s me të tjerët dështoi, ngaqë përdoruesi %s nuk ekziston",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ndarja për %s dështoi, ngaqë përdoruesi %s s’është anëtar i ndonjë grupi ku %s është anëtar",
    "Sharing %s failed, because this item is already shared with %s" : "Ndarja për %s dështoi, ngaqë ky objekt është ndarë një herë me %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Ndarja e %s me të tjerët dështoi, ngaqë ky objekt është ndarë tashmë me përdoruesin %s",
    "Sharing %s failed, because the group %s does not exist" : "Ndarja e %s me të tjerët dështoi, ngaqë grupi %s nuk ekziston",
    "Sharing %s failed, because %s is not a member of the group %s" : "Ndarja e %s me të tjerët dështoi, ngaqë %s s’është anëtar i grupit %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Lypset të jepni një fjalëkalim që të krijoni një lidhje publike, lejohen vetëm lidhje të mbrojtura",
    "Sharing %s failed, because sharing with links is not allowed" : "Ndarja e %s me të tjerët dështoi, ngaqë nuk lejohet ndarja me lidhje",
    "Not allowed to create a federated share with the same user" : "S’i lejohet të krijojë një ndarje të federuar me të njëjtin përdorues",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Ndarja për %s dështoi, s’u gjet dot %s, ndoshta shërbyesi është hëpërhë jashtë pune.",
    "Share type %s is not valid for %s" : "Lloji i ndarjes %s s’është i vlefshëm për %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Caktimi i lejeve për %s dështoi, ngaqë lejet tejkalojnë lejet e akorduara për %s",
    "Setting permissions for %s failed, because the item was not found" : "Caktimi i lejeve për %s dështoi, ngaqë s’u gjet objekti",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "S’caktohet dot data e skadimit. Ndarjet s’mund të skadojnë më vonë se %s pasi të jenë ofruar",
    "Cannot set expiration date. Expiration date is in the past" : "S’caktohet dot data e skadimit. Data e skadimit bie në të kaluarën",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "S’hiqet dot data e skadimit. Ndarjet lypse të kenë një datë skadimi.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Mekanizmi i shërbimit për ndarje %s duhet të sendërtojë ndërfaqen OCP\\Share_Backend",
    "Sharing backend %s not found" : "S’u gjet mekanizmi i shërbimit për ndarje %s",
    "Sharing backend for %s not found" : "S’u gjet mekanizmi i shërbimit për ndarje për %s",
    "Sharing failed, because the user %s is the original sharer" : "Ndarja dështoi, ngaqë përdoruesi %s është ai që e ndau fillimisht",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ndarja e %s me të tjerët dështoi, ngaqë lejet tejkalojnë lejet e akorduara për %s",
    "Sharing %s failed, because resharing is not allowed" : "Ndarja e %s me të tjerët dështoi, ngaqë nuk lejohen rindarje",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ndarja e %s dështoi, ngaqë mekanizmi i shërbimit për ndarje për %s s’gjeti dot burimin për të",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ndarja e %s me të tjerët dështoi, ngaqë kartela s’u gjet dot te fshehtina e kartelave",
    "Cannot increase permissions of %s" : "S’mund të shtohen lejet për %s",
    "Files can't be shared with delete permissions" : "Kartelat s’mund të ndahen me leje fshirjeje",
    "Files can't be shared with create permissions" : "Kartelat s’mund të ndahen me leje krijimi",
    "Expiration date is in the past" : "Data e skadimit bie në të kaluarën",
    "Cannot set expiration date more than %s days in the future" : "S’mund të caktohet data e skadimit më shumë se %s ditë në të ardhmen",
    "Could not find category \"%s\"" : "S’u gjet kategori \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Në një emër përdoruesi lejohen vetëm shenjat vijuese: \"a-z\", \"A-Z\", \"0-9\", dhe \"_.@-\"",
    "A valid username must be provided" : "Duhet dhënë një emër i vlefshëm përdoruesi",
    "Username contains whitespace at the beginning or at the end" : "Emri i përdoruesit përmban hapësirë në fillim ose në fund",
    "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
    "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
    "Login canceled by app" : "Hyrja u anulua nga aplikacioni",
    "User disabled" : "Përdorues i çaktivizuar",
    "Help" : "Ndihmë",
    "Settings" : "Rregullime",
    "Users" : "Përdorues",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Përditësimi \"%s\" s’instalohet dot, ngaqë s’plotësohen varësitë vijuese: %s.",
    "web services under your control" : "shërbime web nën kontrollin tuaj",
    "File is currently busy, please try again later" : "Kartela tani është e zënë, ju lutemi, riprovoni më vonë.",
    "Can't read file" : "S'lexohet dot kartela",
    "Application is not enabled" : "Aplikacioni s’është aktivizuar",
    "Authentication error" : "Gabim mirëfilltësimi",
    "Token expired. Please reload page." : "Token-i ka skaduar. Ju lutemi, ringarkoni faqen.",
    "Unknown user" : "Përdorues i panjohur",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "S’ka baza të dhënash (sqlite, mysql, ose postgresql) të instaluara.",
    "Cannot write into \"config\" directory" : "S’shkruhet dot te drejtoria \"config\"",
    "Cannot write into \"apps\" directory" : "S’shkruhet dot te drejtoria \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Zakonisht kjo mund të ndreqet duke %si akorduar shërbyesit web të drejta shkrimi mbi drejtorinë e aplikacionit%s ose duke e çaktivizuar appstore-in te kartela e formësimit.",
    "Cannot create \"data\" directory" : "S’krijohet dot drejtoria \"data\" ",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Zakonisht kjo mund të ndreqet duke <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">i akorduar shërbyesit web të drejta shkrimi mbi drejtorinë rrënjë</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Zakonisht lejet mund të ndreqen duke %si akorduar shërbyesit web të drejta shkrimi mbi drejtorinë rrënjë%s.",
    "Setting locale to %s failed" : "Caktimi i gjuhës si %s dështoi",
    "Please install one of these locales on your system and restart your webserver." : "Ju lutemi, instaloni te sistemi juaj një prej këtyre vendoreve dhe rinisni shërbyesin tuaj web.",
    "Please ask your server administrator to install the module." : "Ju lutemi, kërkojini përgjegjësit të shërbyesit ta instalojë modulin.",
    "PHP module %s not installed." : "Moduli PHP %s s’është i instaluar.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Rregullimi PHP \"%s\" s’është vënë si \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Saktësimi i këtij rregullimi te php.ini do të bëjë që ownCloud-i të punojë sërish",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload është caktuar si \"%s\", në vend të vlerës së pritshme \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Për ta ndrequr këtë problem, caktoni për <code>mbstring.func_overload</code> vlerën <code>0</code> te php.ini juaj",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Lypset të paktën libxml2 2.7.0. Hëpërhë e instaluar është %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Me sa duket, PHP-ja është rregulluar që të heqë blloqe të brendshëm dokumentimi. Kjo do t’i nxjerrë nga funksionimi disa aplikacione bazë.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Kjo ka gjasa të jetë shkaktuar nga një fshehtinë/përshpejtues i tillë si Zend OPcache ose eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulet PHP janë instaluar, por tregohen ende sikur mungojnë?",
    "Please ask your server administrator to restart the web server." : "Ju lutemi, kërkojini përgjegjësit të shërbyesit tuaj të rinisë shërbyesin web.",
    "PostgreSQL >= 9 required" : "Lypset PostgreSQL >= 9",
    "Please upgrade your database version" : "Ju lutemi, përmirësoni bazën tuaj të të dhënave me një version më të ri.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ju lutemi, kalojani lejet në 0770, që kështu atë drejtori të mos mund ta shfaqin përdorues të tjerë.",
    "Your Data directory is readable by other users" : "Drejtoria juaj Data është e lexueshme nga përdorues të tjerë",
    "Your Data directory must be an absolute path" : "Drejtoria juaj Data duhet të përfaqësohet nga një shteg absolut",
    "Check the value of \"datadirectory\" in your configuration" : "Kontrolloni vlerën e \"datadirectory\" te formësimi juaj",
    "Your Data directory  is invalid" : "Drejtoria juaj Data është e pavlefshme",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Ju lutemi, kontrolloni që drejtoria e të dhënave përmban në rrënjën e saj një kartelë \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "S’u mor dot lloj kyçjeje %d në \"%s\".",
    "Storage unauthorized. %s" : "Depozitë e paautorizuar. %s",
    "Storage incomplete configuration. %s" : "Formësim jo i plotë i depozitës. %s",
    "Storage connection error. %s" : "Gabim lidhje te depozita. %s",
    "Storage is temporarily not available" : "Depozita është përkohësisht jashtë pune",
    "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s",
    "A safe home for all your data" : "Një shtëpi e sigurt për krejt të dhënat tuaja",
    "The username must be at least 3 characters long" : "Emri i përdoruesit duhet të jetë e pakta 3 shenja i gjatë",
    "File cannot be read" : "Kartela s’lexohet dot",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s nuk mbulohet dhe %s s’do të funksionojë si duhet në këtë platformë. Qari dhe zarari, i juaji! ",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Ndarja me të tjerët e %s dështoi, s’u gjet dot %s, kontrollori i drejtshkrimit dhe shërbyesi në punë.",
    "Imprint" : "Imprint",
    "The username can not be longer than 64 characters" : "Emri i përdoruesit s’mund të jetë më i gjatë se 64 shenja",
    "Privacy Policy" : "Rregulla Privatësie",
    "__language_name__" : "Shqip"
},
"nplurals=2; plural=(n != 1);");
